@@ -7,14 +7,14 @@
 #' are determined by \code{prodlim::getStates()} applied to the Hist object.
 #' @param formula Either a single \code{Hist} formula or a list of formulas. 
 #' If it is a list it must contain as many \code{Hist} formulas as there are
-#' causes when \code{survtype="hazard"} and exactly two formulas when \code{survtype="survival"}.
+#' causes when \code{surv.type="hazard"} and exactly two formulas when \code{surv.type="survival"}.
 #' If it is a list the first formula is used for the cause of interest specific Cox regression
 #' and the other formula(s) either for the other cause specific Cox regression(s) or for the
 #' Cox regression of the combined event where each cause counts as event. Note that when only one
 #' formula is given the covariates enter in exactly the same way into all Cox regression analyses.  
 #' @param data A data in which to fit the models.
 #' @param cause The cause of interest. Defaults to the first cause (see Details). 
-#' @param survtype Either \code{"hazard"} (the default) or
+#' @param surv.type Either \code{"hazard"} (the default) or
 #' \code{"survival"}.  If \code{"hazard"} fit cause-specific Cox
 #' regression models for all causes.  If \code{"survival"} fit one
 #' cause-specific Cox regression model for the cause of interest and
@@ -24,8 +24,8 @@
 #' @param ... Arguments given to \code{coxph}.
 #' @return \item{models }{a list with the fitted (cause-specific) Cox
 #' regression objects} \item{response }{the event history response }
-#' \item{eventTimes }{the sorted (unique) event times } \item{survtype }{the
-#' value of \code{survtype}} \item{theCause }{the cause of interest. see
+#' \item{eventTimes }{the sorted (unique) event times } \item{surv.type }{the
+#' value of \code{surv.type}} \item{theCause }{the cause of interest. see
 #' \code{cause}} \item{causes }{the other causes} %% ...
 #' @author Thomas A. Gerds \email{tag@@biostat.ku.dk} and Ulla B. Mogensen
 #' @references
@@ -54,7 +54,7 @@
 ##' ## model hazard of all cause mortality instead of hazard of type 2 
 ##' fit1a <- CSC(list(Hist(time,status)~sex+age,Hist(time,status)~invasion+epicel+log(thick)),
 ##'              data=Melanoma,
-##'              survtype="surv")
+##'              surv.type="surv")
 ##' print(fit1a)
 ##'
 ##' ## special case where cause 2 has no covariates
@@ -74,20 +74,20 @@
 ##' ## different formula for cause 2 and event-free survival
 ##' fit3 <- CSC(list(Hist(time,status)~sex+invasion+epicel+age,
 ##'                  Hist(time,status)~invasion+epicel+age),
-##'             survtype="surv",
+##'             surv.type="surv",
 ##'             data=Melanoma)
 ##' print(fit3)
 ##' 
 ##' ## same formula for both causes
 ##' fit4 <- CSC(Hist(time,status)~invasion+epicel+age,
 ##'             data=Melanoma,
-##'             survtype="surv")
+##'             surv.type="surv")
 ##' print(fit4)
 ##'
 ##' ## strata
 ##' fit5 <- CSC(Hist(time,status)~invasion+epicel+age+strata(sex),
 ##'             data=Melanoma,
-##'             survtype="surv")
+##'             surv.type="surv")
 ##' print(fit5)
 ##'
 ##' ## sanity checks
@@ -99,7 +99,7 @@
 ##'
 ##' ## predictions
 ##' ##
-##' ## survtype = "hazard": predictions for both causes can be extracted
+##' ## surv.type = "hazard": predictions for both causes can be extracted
 ##' ## from the same fit
 ##' fit2 <- CSC(Hist(time,status)~invasion+epicel+age, data=Melanoma)
 ##' predict(fit2,cause=1,newdata=Melanoma[c(17,99,108),],times=c(100,1000,10000))
@@ -108,11 +108,11 @@
 ##' predict(fit2,cause=1,newdata=Melanoma[c(17,99,108),],times=c(100,1000,10000))
 ##' predict(fit2,cause=2,newdata=Melanoma[c(17,99,108),],times=c(100,1000,10000))
 ##' 
-##' ## survtype = "surv" we need to change the cause of interest 
+##' ## surv.type = "surv" we need to change the cause of interest 
 ##' library(survival)
 ##' fit5.2 <- CSC(Hist(time,status)~invasion+epicel+age+strata(sex),
 ##'             data=Melanoma,
-##'             survtype="surv",cause=2)
+##'             surv.type="surv",cause=2)
 ##' ## now this does not work
 ##' try(predictRisk(fit5.2,cause=1,newdata=Melanoma,times=4))
 ##' 
@@ -125,39 +125,55 @@
 CSC <- function(formula,
                 data,
                 cause,
-                survtype="hazard",
+                surv.type="hazard",
                 fitter="coxph",
                 ## strip.environment
                 ...){
     fitter <- match.arg(fitter,c("coxph","cph","phreg"))
     # {{{ type
-    survtype <- match.arg(survtype,c("hazard","survival"))
+    surv.type <- match.arg(surv.type,c("hazard","survival"))
     # }}}
-    # {{{ formulae
+    # {{{ formulae & response
     if (class(formula)=="formula") formula <- list(formula)
-    else if (!length(formula)<=4) stop("Formula can either be a single formula (to be used for both cause specific hazards) or a list of formulae, one for each cause.")
-    responseFormula <- reformulate("1", formula[[1]][[2]])
-    # }}}
-    # {{{ response
-    ## require(survival)
     call <- match.call()
-    # get information from formula
-    mf <- stats::model.frame(update(responseFormula,".~1"), data = data, na.action = na.omit)
-    response <- stats::model.response(mf)
+    # get outcome information from formula
+    Rform <- update(formula[[1]],".~1")
+    ## mf <- stats::model.frame(Rform, data = data, na.action = na.omit)
+    ## response <- stats::model.response(mf)
+    response <- eval(Rform[[2]],envir=data)
+    if (any(is.na(response))) 
+        stop("Event history response may not contain missing values")
     time <- response[, "time"]
     status <- response[, "status"]
     event <- prodlim::getEvent(response)
+    if ("entry" %in% colnames(response))
+        entry <- response[, "entry"]
+    else{
+        if(fitter=="phreg"){
+            entry <- 0
+        }else{
+            entry <- NULL
+        }
+    }
+    if (any(entry>time)) stop("entry > time detected. Entry into the study must come first.")
+    ## remove event history variables from data
+    if(any((this <- match(all.vars(Rform),names(data),nomatch=0))>0)){
+        if (is.data.table(data))
+            data <- data[,-this,with=FALSE]
+        else
+            data <- data[,-this]
+    }
     # }}}
-    # {{{ event times
+    # {{{ sorted unique event times
     eventTimes <- unique(sort(as.numeric(time[status != 0])))
     # }}}
     # {{{ causes
     causes <- prodlim::getStates(response)
-    if (survtype=="hazard")
+    if (surv.type=="hazard")
         NC <- length(causes)
     else
         NC <- 2 # cause of interest and overall survival
-    if (length(formula)!=NC && length(formula)>1) stop("Wrong number of formulae. Should be ",NC,".")
+    if (length(formula)!=NC && length(formula)>1) stop("Wrong number of formulae. Should be one for each cause ",NC,".")
     if (length(formula)==1) {
         ## warning("The same formula used for all causes")
         formula <- lapply(1:NC,function(x)formula[[1]])
@@ -169,7 +185,10 @@ CSC <- function(formula,
     }
     else{
         if ((foundCause <- match(as.character(cause),causes,nomatch=0))==0)
-            stop(paste("Requested cause: ",cause," Available causes: ", causes))
+            stop(paste0("Cannot find all requested cause(s) ...\n\n", 
+                        "Requested cause(s): ", paste0(cause, collapse = ", "), 
+                        "\n Available causes: ", paste(causes, collapse = ", "), 
+                        "\n"))
         else{
             theCause <- causes[foundCause]
         }
@@ -177,36 +196,27 @@ CSC <- function(formula,
     otherCauses <- causes[-match(theCause,causes)]
     # }}}
     # {{{ fit Cox models
-    if (survtype=="hazard"){
+    if (surv.type=="hazard"){
         nmodels <- NC
     }else {
         nmodels <- 2}
     CoxModels <- lapply(1:nmodels,function(x){
-        if (survtype=="hazard"){
+        if (surv.type=="hazard"){
             if (x==1)
                 causeX <- theCause
             else
-                causeX <- otherCauses[x-1]}
-        else{
+                causeX <- otherCauses[x-1]
+        } else{
             causeX <- theCause
         }
-        EHF <- prodlim::EventHistory.frame(formula=formula[[x]],
-                                           data=data,
-                                           unspecialsDesign=FALSE,
-                                           specialsFactor=FALSE,
-                                           specials="strata",
-                                           stripSpecials="strata",
-                                           stripArguments=list("strata"=NULL),
-                                           specialsDesign=FALSE)
-        formulaX <- formula[[x]]
-        if (is.null(EHF$strata))
-            covData <- cbind(EHF$design)
-        else
-            covData <- cbind(EHF$design,EHF$strata)
-        ## response <- stats::model.response(covData)
-        time <- as.numeric(EHF$event.history[, "time",drop=TRUE])
-        event <- prodlim::getEvent(EHF$event.history)
-        if (survtype=="hazard"){
+        ## EHF <- prodlim::EventHistory.frame(formula=formula[[x]],data=data,unspecialsDesign=FALSE,specialsFactor=FALSE,specials="strata",stripSpecials="strata",stripArguments=list("strata"=NULL),specialsDesign=FALSE)
+        ## if (is.null(EHF$strata))
+        ## covData <- cbind(EHF$design)
+        ## else
+        ## covData <- cbind(EHF$design,EHF$strata)
+        ## time <- as.numeric(EHF$event.history[, "time",drop=TRUE])
+        ## event <- prodlim::getEvent(EHF$event.history)
+        if (surv.type=="hazard"){
             statusX <- as.numeric(event==causeX)
         }else{
             if (x==1){
@@ -216,24 +226,26 @@ CSC <- function(formula,
                 statusX <- response[,"status"]
             }
         }
-        
-        workData <- data.frame(time=time,status=statusX)
-        if(fitter=="phreg"){
-            if("entry" %in% names(data)){
-                stop("data may not contain a column named \"entry\" when using fitter=\"phreg\"")
-            }
-            workData$entry <- 0
+        if (is.null(entry))
+            workData <- data.frame(time=time,status=statusX)
+        else
+            workData <- data.frame(time=time,status=statusX,entry=entry)
+        if(any(this <- match(names(data),names(workData),nomatch=0)>0)){
+            warning(paste("Variables named",paste(names(data)[this],collapse=", "),"in data will be ignored."))
+            if (is.data.table(data))
+                data <- data[,-this,with=FALSE]
+            else
+                data <- data[,-this]
         }
-        ## to interprete formula
-        ## we need the variables. in case of log(age) terms
-        ## covData has wrong names 
-        ## workData <- cbind(workData,covData)
         workData <- cbind(workData,data)
-        
-        response <- paste0("survival::Surv(",if(fitter=="phreg"){"entry,"},"time, status)")
-        formulaXX <- as.formula(paste(response,
-                                      as.character(delete.response(terms.formula(formulaX)))[[2]],
-                                      sep="~"))
+        if (is.null(entry))
+            survresponse <- "survival::Surv(time, status)"
+        else
+            survresponse <- "survival::Surv(entry, time, status)"
+        formulaXX <- update(formula[[x]],paste0(survresponse,"~."))
+        ## as.formula(paste(survresponse,
+        ## as.character(delete.response(terms.formula(formulaX)))[[2]],
+        ## sep="~"))
         if (fitter=="coxph"){
             fit <- survival::coxph(formulaXX, data = workData,x=TRUE,y=TRUE,...)
         } else if(fitter=="cph") {
@@ -249,7 +261,7 @@ CSC <- function(formula,
         fit$call$data <- workData
         fit
     })
-    if (survtype=="hazard"){
+    if (surv.type=="hazard"){
         names(CoxModels) <- paste("Cause",c(theCause,otherCauses))
     }else{
         names(CoxModels) <- c(paste("Cause",theCause),"OverallSurvival")
@@ -259,7 +271,7 @@ CSC <- function(formula,
                 models=CoxModels,
                 response=response,
                 eventTimes=eventTimes,
-                survtype=survtype,
+                surv.type=surv.type,
                 fitter=fitter,
                 theCause=theCause,
                 causes=c(theCause,otherCauses))
