@@ -3,9 +3,9 @@
 ## author: Brice Ozenne
 ## created: feb 17 2017 (10:06) 
 ## Version: 
-## last-updated: Jun 29 2017 (16:56) 
+## last-updated: Feb 19 2018 (17:58) 
 ##           By: Thomas Alexander Gerds
-##     Update #: 330
+##     Update #: 333
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -20,10 +20,13 @@
 #' @description Plot predictions from a Cox model
 #' 
 #' @param object object obtained with the function \code{predictCox}.
-#' @inheritParams predictCox
+#' @param type the type of predicted value to display. Choices are 
+#' \code{"hazard"} the hazard function,
+#' \code{"cumhazard"} the cumulative hazard function, 
+#' or \code{"survival"} the survival function.
 #' @param ci Logical. If \code{TRUE} display the confidence intervals for the predictions.
 #' @param band Logical. If \code{TRUE} display the confidence bands for the predictions.
-#' @param groupBy The grouping factor used to color the prediction curves. Can be \code{"row"}, \code{"strata"}, or \code{"covariates"}.
+#' @param group.by The grouping factor used to color the prediction curves. Can be \code{"row"}, \code{"strata"}, or \code{"covariates"}.
 #' @param reduce.data Logical. If \code{TRUE} only the covariates that does take indentical values for all observations are displayed.
 #' @param plot Logical. Should the graphic be plotted.
 #' @param digits integer indicating the number of decimal places
@@ -44,8 +47,8 @@
 #' pred.cox <- predictCox(m.cox, newdata = d[1:4,],
 #'   times = 1:5, type = "survival", keep.newdata = TRUE)
 #' autoplot(pred.cox)
-#' autoplot(pred.cox, groupBy = "covariates")
-#' autoplot(pred.cox, groupBy = "covariates", reduce.data = TRUE)
+#' autoplot(pred.cox, group.by = "covariates")
+#' autoplot(pred.cox, group.by = "covariates", reduce.data = TRUE)
 #' 
 #' 
 #' m.cox.strata <- coxph(Surv(time,event)~ strata(X1) + strata(X2) + X3 + X6,
@@ -53,9 +56,9 @@
 #' pred.cox.strata <- predictCox(m.cox.strata, newdata = d[1,,drop=FALSE],
 #' time = 1:5, keep.newdata = TRUE)
 #' autoplot(pred.cox.strata, type = "survival")
-#' autoplot(pred.cox.strata, type = "survival", groupBy = "strata")
+#' autoplot(pred.cox.strata, type = "survival", group.by = "strata")
 #' res <- autoplot(pred.cox.strata, type = "survival",
-#'             groupBy = "covariates")
+#'             group.by = "covariates")
 #'
 #' # customize display
 #' res$plot + geom_point(data = res$data, size = 5)
@@ -67,7 +70,7 @@
 #'
 #' ## predictions with confidence bands
 #' pred.cox <- predictCox(m.cox, newdata = d[1,,drop=FALSE],
-#'   times = 1:5, type = "survival", nSim.band = 500,  band = TRUE, keep.newdata = TRUE)
+#'   times = 1:5, type = "survival", nsim.band = 500,  band = TRUE, keep.newdata = TRUE)
 #' autoplot(pred.cox, band = TRUE)
 #'
 #' 
@@ -77,7 +80,7 @@ autoplot.predictCox <- function(object,
                             type = NULL,
                             ci = FALSE,
                             band = FALSE,
-                            groupBy = "row",
+                            group.by = "row",
                             reduce.data = FALSE,
                             plot = TRUE,
                             digits = 2, alpha = NA, ...){
@@ -85,34 +88,30 @@ autoplot.predictCox <- function(object,
   ## initialize and check    
   possibleType <- c("hazard","cumhazard","survival")
   possibleType <- possibleType[possibleType %in% names(object)]
-  
+
   if(is.null(type)){
     if(length(possibleType) == 1){
       type <- possibleType
     }else{
       stop("argument \'type\' must be specified to choose between ",paste(possibleType, collapse = " "),"\n")
     }
-  }else if(length(type)>1){
-    stop("argument \'type\' must have length 1 \n")        
-  }else if(type %in% possibleType == FALSE){
-    stop("argument \'type\' can only be ",paste(possibleType, collapse = " or ")," \n")        
-  }
+  }else{
+    type <- match.arg(type, possibleType)  
+  } 
   typename <- switch(type,
                      hazard = "hazard",
                      cumhazard = "cumulative hazard",
                      survival = "survival")
   
-  possibleGroupBy <- c("row","covariates","strata")
-  if(groupBy %in% possibleGroupBy == FALSE){
-    stop("argument \"groupBy\" must be in \"",paste(possibleGroupBy, collapse = "\" \""),"\"\n")
-  }
+  group.by <- match.arg(group.by, c("row","covariates","strata"))
+ 
   
-  if(groupBy == "covariates" && ("newdata" %in% names(object) == FALSE)){
-    stop("argument \'groupBy\' cannot be \"covariates\" when newdata is missing in the object \n",
+  if(group.by == "covariates" && ("newdata" %in% names(object) == FALSE)){
+    stop("argument \'group.by\' cannot be \"covariates\" when newdata is missing in the object \n",
          "set argment \'keep.newdata\' to TRUE when calling predictCox \n")
   }
-  if(groupBy == "strata" && ("strata" %in% names(object) == FALSE)){
-    stop("argument \'groupBy\' cannot be \"strata\" when strata is missing in the object \n",
+  if(group.by == "strata" && ("strata" %in% names(object) == FALSE)){
+    stop("argument \'group.by\' cannot be \"strata\" when strata is missing in the object \n",
          "set argment \'keep.strata\' to TRUE when calling predictCox \n")
   }
   
@@ -128,7 +127,7 @@ autoplot.predictCox <- function(object,
 
     if(band && object$band == FALSE){
         stop("argument \'band\' cannot be TRUE when no quantiles for the confidence bands have not been computed \n",
-             "set argment \'nSim.band\' to a positive integer when calling predictCox \n")
+             "set argment \'nsim.band\' to a positive integer when calling predictCox \n")
     }
     
     ## display
@@ -149,7 +148,7 @@ autoplot.predictCox <- function(object,
                           strata = object$strata,
                           times = object$times,
                           name.outcome = typename,
-                          groupBy = groupBy,
+                          group.by = group.by,
                           digits = digits
                           )
 
@@ -157,7 +156,7 @@ autoplot.predictCox <- function(object,
                            name.outcome = typename,
                            ci = ci,
                            band = band,
-                           groupBy = groupBy,
+                           group.by = group.by,
                            conf.level = object$conf.level,
                            alpha = alpha,
                            origin = min(object$times)
@@ -175,7 +174,7 @@ autoplot.predictCox <- function(object,
 predict2melt <- function(outcome, name.outcome,
                          ci, outcome.lower, outcome.upper,
                          band, outcome.lowerBand, outcome.upperBand,
-                         newdata, strata, times, groupBy, digits){
+                         newdata, strata, times, group.by, digits){
 
     ## for CRAN tests
     patterns <- function(){}
@@ -187,7 +186,7 @@ predict2melt <- function(outcome, name.outcome,
         time.names <- 1:n.time
     }    
     colnames(outcome) <- paste0(name.outcome,"_",time.names)
-    keep.cols <- unique(c("time",name.outcome,"row",groupBy))
+    keep.cols <- unique(c("time",name.outcome,"row",group.by))
     
     #### merge outcome with CI and band ####
     pattern <- paste0(name.outcome,"_")
@@ -213,16 +212,18 @@ predict2melt <- function(outcome, name.outcome,
 
     #### merge with convariates ####
     outcome[, row := 1:.N]
-    if(groupBy == "covariates"){
+    if(group.by == "covariates"){
         cov.names <- names(newdata)
-        newdata <- newdata[, (cov.names) := lapply(cov.names, function(col){paste0(col,"=",round(.SD[[col]],digits))})]
+        newdata <- newdata[, (cov.names) := lapply(cov.names,function(col){
+            if (is.numeric(.SD[[col]]))
+                paste0(col,"=",round(.SD[[col]],digits)) else paste0(col,"=",.SD[[col]])})]
         outcome[, ("covariates") := interaction(newdata,sep = " ")]
-    }else if(groupBy == "strata"){
+    }else if(group.by == "strata"){
         outcome[, strata := strata]
     }
     
     #### reshape to long format ####
-    dataL <- melt(outcome, id.vars = union("row",groupBy),
+    dataL <- melt(outcome, id.vars = union("row",group.by),
                    measure= patterns(pattern),
                    variable.name = "time", value.name = gsub("_","",pattern))
     dataL[, time := as.numeric(as.character(factor(time, labels = time.names)))]
@@ -233,13 +234,13 @@ predict2melt <- function(outcome, name.outcome,
 # }}}
 # {{{ predict2plot
 predict2plot <- function(dataL, name.outcome,
-                         ci, band, groupBy,                         
+                         ci, band, group.by,                         
                          conf.level, alpha, origin){
 
     # for CRAN tests
     original <- lowerCI <- upperCI <- lowerBand <- upperBand <- NULL
     #### duplicate observations to obtain step curves ####
-    keep.cols <- unique(c("time",name.outcome,"row",groupBy,"original"))
+    keep.cols <- unique(c("time",name.outcome,"row",group.by,"original"))
     if(ci){
         keep.cols <- c(keep.cols,"lowerCI","upperCI")
     }
@@ -260,9 +261,9 @@ predict2plot <- function(dataL, name.outcome,
     labelCI <- paste0(conf.level*100,"% confidence \n interval")
     labelBand <- paste0(conf.level*100,"% confidence \n band")
 
-    gg.base <- ggplot(mapping = aes_string(x = "time", y = name.outcome, group = "row", color = groupBy))
+    gg.base <- ggplot(mapping = aes_string(x = "time", y = name.outcome, group = "row", color = group.by))
     gg.base <- gg.base + geom_line(data = dataL, size = 2)
-    if(groupBy=="row"){
+    if(group.by=="row"){
         gg.base <- gg.base + ggplot2::labs(color="observation") + theme(legend.key.height=unit(0.1,"npc"),
                                                                         legend.key.width=unit(0.08,"npc"))
         
