@@ -3,9 +3,9 @@
 ## author: Thomas Alexander Gerds
 ## created: Feb 23 2017 (11:15) 
 ## Version: 
-## last-updated: jun  6 2017 (07:39) 
-##           By: Brice
-##     Update #: 121
+## last-updated: Feb  6 2018 (17:03) 
+##           By: Thomas Alexander Gerds
+##     Update #: 251
 #----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -21,10 +21,6 @@
 ##' @param x Object obtained with function \code{Score}
 ##' @param models Choice of models to plot
 ##' @param times Time point specifying the prediction horizon.
-##' @param showPseudo If \code{TRUE} the pseudo-values are shown as
-##'     dots on the plot (only when \code{pseudo=TRUE}).
-##' @param pseudo.col Colour for pseudo-values.
-##' @param pseudo.pch Dot type (see par) for pseudo-values.
 ##' @param method The method for estimating the calibration curve(s):
 ##' 
 ##' \code{"nne"}: The expected event status is obtained in the nearest
@@ -44,15 +40,20 @@
 ##'     corresponding prediction.
 ##' @param names Barplots only. Names argument passed to
 ##'     \code{names.arg} of \code{barplot}.
-##' @param showFrequencies Barplots only. If \code{TRUE}, show
+##' @param pseudo If \code{TRUE} show pseudo values (only for right
+##'     censored data).
+##' @param rug If \code{TRUE} show rug plot at the predictions
+##' @param show.frequencies Barplots only. If \code{TRUE}, show
 ##'     frequencies above the bars.
-##' @param jack.density Gray scale for pseudo-observations.
 ##' @param plot If \code{FALSE}, do not plot the results, just return
 ##'     a plottable object.
 ##' @param add If \code{TRUE} the line(s) are added to an existing
 ##'     plot.
 ##' @param diag If \code{FALSE} no diagonal line is drawn.
 ##' @param legend Logical. If \code{TRUE} draw legend.
+##' @param auc.in.legend Logical. If \code{TRUE} add AUC to legend.
+##' @param brier.in.legend Logical. If \code{TRUE} add Brier score to
+##'     legend.
 ##' @param axes If \code{FALSE} no axes are drawn.
 ##' @param xlim Limits of x-axis.
 ##' @param ylim Limits of y-axis.
@@ -74,15 +75,28 @@
 ##'     \code{\link{model.frame}}
 ##' @param cex Default cex used for legend and labels.
 ##' @param ... Used to control the subroutines: plot, axis, lines,
-##'     barplot, legend. See \code{\link{SmartControl}}.
+##'     barplot, legend, addtable2plot, points (pseudo values), rug. See
+##'     \code{\link{SmartControl}}.
 ##' @examples
+##' # binary 
 ##' db=sampleData(100,outcome="binary")
 ##' fb1=glm(Y~X1+X5+X7,data=db,family="binomial")
 ##' fb2=glm(Y~X1+X3+X6+X7,data=db,family="binomial")
 ##' xb=Score(list(model1=fb1,model2=fb2),Y~1,data=db,
-##'           plots="cal",metrics=NULL)
+##'           plots="cal")
 ##' plotCalibration(xb)
 ##' 
+##' # survival
+##' library(survival)
+##' ds=sampleData(100,outcome="survival")
+##' fs1=coxph(Surv(time,event)~X1+X5+X7,data=ds,x=1)
+##' fs2=coxph(Surv(time,event)~X1+X3+X6+X7,data=ds,x=1)
+##' xs=Score(list(Cox1=fs1,Cox2=fs2),Surv(time,event)~1,data=ds,
+##'           plots="cal",metrics=NULL)
+##' plotCalibration(xs)
+##'
+##'
+##' # competing risks
 ##' data(Melanoma)
 ##' f1 <- CSC(Hist(time,status)~age+sex+epicel+ulcer,data=Melanoma)
 ##' f2 <- CSC(Hist(time,status)~age+sex+logthick+epicel+ulcer,data=Melanoma)
@@ -92,9 +106,6 @@
 plotCalibration <- function(x,
                             models,
                             times,
-                            showPseudo,
-                            pseudo.col=NULL,
-                            pseudo.pch=NULL,
                             method="nne",
                             round=TRUE,
                             bandwidth=NULL,
@@ -102,12 +113,15 @@ plotCalibration <- function(x,
                             bars=FALSE,
                             hanging=FALSE,
                             names="quantiles",
-                            showFrequencies=FALSE,
-                            jack.density=55,
+                            pseudo,
+                            rug,
+                            show.frequencies=FALSE,
                             plot=TRUE,
                             add=FALSE,
                             diag=!add,
                             legend=!add,
+                            auc.in.legend=TRUE,
+                            brier.in.legend=TRUE,
                             axes=!add,
                             xlim=c(0,1),
                             ylim=c(0,1),
@@ -124,10 +138,19 @@ plotCalibration <- function(x,
                             cex=1,
                             ...){
     # {{{ plot frame
-    pseudo=1L
-    model=NULL
-    if (missing(showPseudo)) 
-        showPseudo <- x$censType=="rightCensored"
+    model=risk=NULL
+    if (missing(pseudo) & missing(rug))
+        if (x$cens.type=="rightCensored"){
+            showPseudo <- TRUE
+            showRug <- FALSE
+        } else{
+            showPseudo <- FALSE
+            showRug <- TRUE
+        }
+    else{ 
+            if (missing(pseudo) || pseudo==FALSE) showPseudo <- FALSE else showPseudo <- TRUE
+            if (missing(rug) || rug==FALSE) showRug <- FALSE else showRug <- TRUE
+        }
     pframe <- x$Calibration$plotframe
     if (is.null(pframe))
         stop("Object has no information for calibration plot.\nYou should call the function \"riskRegression::Score\" with plots=\"calibration\".")
@@ -136,13 +159,18 @@ plotCalibration <- function(x,
         pframe <- pframe[model%in%models]
     }
     data.table::setkey(pframe,model)
-    if (x$responseType!="binary"){
-        if (missing(times))
+    if (x$response.type!="binary"){
+        if (missing(times)){
             tp <- max(pframe[["times"]])
-        else ## can only do one time point
+            if (length(unique(pframe$times))>1)
+                warning("Time point not specified, use max of the available times: ",tp)
+        } else{ ## can only do one time point
             tp <- times[[1]]
+            if (!(tp%in%unique(pframe$times)))
+                stop(paste0("Requested time ",times[[1]]," is not in object"))
+        }
         pframe <- pframe[times==tp]
-    }
+    }else tp <- NULL
     ## plot(0,0,type="n",ylim = 0:1,xlim = 0:1,axes=FALSE,xlab = xlab,ylab = ylab)
     NF <- pframe[,length(unique(model))]
     if (bars){
@@ -162,30 +190,59 @@ plotCalibration <- function(x,
     }
     if (missing(type)){
         if (method=="quantile"){
-            type <- rep("b",NF)
+            type <- rep("b",length.out=NF)
         } else{
-            type <- rep("l",NF)
+            type <- rep("l",length.out=NF)
         }
     }
-    if (missing(lty)) lty <- rep(1, NF)
-    if (missing(pch)) pch <- rep(1, NF)
-    if (length(lwd) < NF) lwd <- rep(lwd, NF)
-    if (length(type) < NF) type <- rep(type, NF)
-    if (length(lty) < NF) lty <- rep(lty, NF)
-    if (length(col) < NF) col <- rep(col, NF)
-    if (length(pch) < NF) pch <- rep(pch, NF)
+    if (missing(lty)) lty <- rep(1, length.out=NF)
+    if (missing(pch)) pch <- rep(1, length.out=NF)
+    if (length(lwd) < NF) lwd <- rep(lwd, length.out=NF)
+    if (length(type) < NF) type <- rep(type,length.out=NF)
+    if (length(lty) < NF) lty <- rep(lty,length.out=NF)
+    if (length(col) < NF) col <- rep(col,length.out=NF)
+    if (length(pch) < NF) pch <- rep(pch,length.out=NF)
 
     # }}}
     # {{{ SmartControl
     modelnames <- pframe[,unique(model)]
     axis1.DefaultArgs <- list(side=1,las=1,at=seq(0,xlim[2],xlim[2]/4))
     axis2.DefaultArgs <- list(side=2,las=2,at=seq(0,ylim[2],ylim[2]/4),mgp=c(4,1,0))
+    if (is.character(legend[1])|| legend[1]==TRUE){
+        legend.data <- getLegendData(object=x,
+                                     models=models,
+                                     times=tp,
+                                     auc.in.legend=auc.in.legend,
+                                     brier.in.legend=brier.in.legend,
+                                     drop.null.model=TRUE)
+        if (is.character(legend))
+            legend.text <- legend
+        else
+            legend.text <- unlist(legend.data[,1])
+        nrows.legend <- NROW(legend.data)
+        if (nrows.legend==1){
+            legend.lwd <- NA
+        } else{ 
+            legend.lwd <- lwd
+        }
+        legend.DefaultArgs <- list(legend=legend.text,lwd=legend.lwd,col=col,ncol=1,lty=lty,cex=cex,bty="n",y.intersp=1,x="topleft",title="")
+        if (NCOL(legend.data)>1){
+            addtable2plot.DefaultArgs <- list(yjust=1.18,cex=cex, table=legend.data[,-1,drop=FALSE])
+        }else{
+            addtable2plot.DefaultArgs <- NULL
+        }
+    }else{
+        legend.DefaultArgs <- NULL
+        addtable2plot.DefaultArgs <- NULL
+    }
     if (bars){
         legend.DefaultArgs <- list(legend=modelnames,col=col,cex=cex,bty="n",x="topleft")
         names.DefaultArgs <- list(cex=.7*par()$cex,y=c(-abs(diff(ylim))/15,-abs(diff(ylim))/25))
         frequencies.DefaultArgs <- list(cex=.7*par()$cex,percent=FALSE,offset=0)
     } else{
-        legend.DefaultArgs <- list(legend=modelnames,lwd=lwd,col=col,lty=lty,cex=cex,bty="n",y.intersp=1.3,x="topleft")
+        if (length(modelnames)<=1){
+            legend=FALSE
+        }
     }
     if(bars){
         legend.DefaultArgs$legend <- c("Predicted risks","Observed frequencies")
@@ -209,6 +266,8 @@ plotCalibration <- function(x,
                              xlim = xlim,
                              ylab=ylab,
                              xlab=xlab)
+    rug.DefaultArgs <- list(col=col,lwd=lwd,side=1,ticksize=0.03)
+    pseudo.DefaultArgs <- list(col=col,cex=cex,density=55)
     barplot.DefaultArgs <- list(ylim = ylim,
                                 col=col,
                                 axes=FALSE,
@@ -221,10 +280,11 @@ plotCalibration <- function(x,
                                 cex.names=cex)
     if (bars){
         control <- prodlim::SmartControl(call= list(...),
-                                         keys=c("barplot","legend","axis2","abline","names","frequencies"),
+                                         keys=c("barplot","legend","addtable2plot","axis2","abline","names","frequencies"),
                                          ignore=NULL,
                                          ignore.case=TRUE,
                                          defaults=list("barplot"=barplot.DefaultArgs,
+                                                       "addtable2plot"=addtable2plot.DefaultArgs,
                                                        "abline"=abline.DefaultArgs,
                                                        "legend"=legend.DefaultArgs,
                                                        "names"=names.DefaultArgs,
@@ -234,10 +294,11 @@ plotCalibration <- function(x,
                                          verbose=TRUE)
     }else{
         control <- prodlim::SmartControl(call= list(...),
-                                         keys=c("plot","lines","legend","axis1","axis2"),
+                                         keys=c("plot","rug","pseudo","lines","legend","addtable2plot","axis1","axis2"),
                                          ignore=NULL,
                                          ignore.case=TRUE,
-                                         defaults=list("plot"=plot.DefaultArgs,
+                                         defaults=list("plot"=plot.DefaultArgs,"pseudo"=pseudo.DefaultArgs,"rug"=rug.DefaultArgs,
+                                                       "addtable2plot"=addtable2plot.DefaultArgs,
                                                        "lines"=lines.DefaultArgs,
                                                        "legend"=legend.DefaultArgs,
                                                        "axis1"=axis1.DefaultArgs,
@@ -251,12 +312,8 @@ plotCalibration <- function(x,
     method <- match.arg(method,c("quantile","nne"))
     getXY <- function(f){
         risk=NULL
-        ## if(pseudo==TRUE){
         p <- pframe[model==f,risk]
         jackF <- pframe[model==f][[Rvar]]
-        ## }else{
-        ## p <- pframe[model==f,risk]
-        ## }
         switch(method,
                "quantile"={
                    if (length(q)==1)
@@ -266,44 +323,26 @@ plotCalibration <- function(x,
                    }
                    xgroups <- (groups[-(length(groups))]+groups[-1])/2
                    pcut <- cut(p,groups,include.lowest=TRUE)
-                   ## if (x$censType=="rightCensored"){
+                   ## if (x$cens.type=="rightCensored"){
                    plotFrame=data.frame(Pred=tapply(p,pcut,mean),Obs=pmin(1,pmax(0,tapply(jackF,pcut,mean))))
                    attr(plotFrame,"quantiles") <- groups
                    plotFrame
-                   ## }
-                   ## else{
-                   ## form.pcut <- update(formula,paste(".~pcut"))
-                   ## if ("data.table" %in% class(data))
-                   ## pdata <- cbind(data[,all.vars(update(formula,".~1")),drop=FALSE,with=FALSE],pcut=pcut)
-                   ## else
-                   ## pdata <- cbind(data[,all.vars(update(formula,".~1")),drop=FALSE],pcut=pcut)
-                   ## y <- unlist(predict(f <- prodlim::prodlim(form.pcut,data=pdata),
-                   ## cause=cause,
-                   ## newdata=data.frame(pcut=levels(pcut)),
-                   ## times=time,
-                   ## type=ifelse(x$responseType=="survival","surv","cuminc")))
-                   ## ## Is it ok to extrapolate into the future??
-                   ## y[is.na(y)] <- max(y,na.rm=TRUE)
-                   ## plotFrame=data.frame(Pred=tapply(p,pcut,mean),Obs=y)
-                   ## attr(plotFrame,"quantiles") <- groups
-                   ## plotFrame}
                },
                "nne"={
-                   if (pseudo==TRUE){
-                       ## Round probabilities to 2 digits
-                       ## to avoid memory explosion ...
-                       ## a difference in the 3 digit should
-                       ## not play a role for the single subject.
-                       if (round==TRUE){
-                           if (!is.null(bandwidth) && bandwidth>=1){
-                               ## message("No need to round predicted probabilities to calculate calibration in the large")
-                           } else{
-                               p <- round(p,2)
-                           }
+                   ## Round probabilities to 2 digits
+                   ## to avoid memory explosion ...
+                   ## a difference in the 3 digit should
+                   ## not play a role for the single subject.
+                   if (round==TRUE){
+                       if (!is.null(bandwidth) && bandwidth>=1){
+                           ## message("No need to round predicted probabilities to calculate calibration in the large")
+                       } else{
+                           p <- round(p,2)
                        }
-                       p <- na.omit(p)
-                       if (no <- length(attr(p,"na.action")))
-                           warning("calPlot: removed ",no," missing values in risk prediction.",call.=FALSE,immediate.=TRUE)
+                   }
+                   p <- na.omit(p)
+                   if (no <- length(attr(p,"na.action")))
+                       warning("calPlot: removed ",no," missing values in risk prediction.",call.=FALSE,immediate.=TRUE)
                        if (is.null(bandwidth)){
                            ## if (length(p)>length(apppred[,f+1])){
                            ## bw <- prodlim::neighborhood(apppred[,f+1])$bandwidth
@@ -320,26 +359,12 @@ plotCalibration <- function(x,
                            ## calibration in the large
                            plotFrame <- data.frame(Pred=mean(p),Obs=mean(jackF))
                        } else{
+                           ## nn <- prodlim::neighborhood(x=p,bandwidth=bw)
                            nbh <- prodlim::meanNeighbors(x=p,y=jackF,bandwidth=bw)
                            plotFrame <- data.frame(Pred=nbh$uniqueX,Obs=nbh$averageY)
                        }
                        attr(plotFrame,"bandwidth") <- bw
                        plotFrame
-                   }else{
-                       stop("Method mot ported yet")
-                       ## form.p <- update(formula,paste(".~p"))
-                       ## if ("data.table" %in% class(data))
-                       ## pdata <- cbind(data[,all.vars(update(formula,".~1")),drop=FALSE,with=FALSE],p=p)
-                       ## else
-                       ## pdata <- cbind(data[,all.vars(update(formula,".~1")),drop=FALSE],p=p)
-                       ## y <- unlist(predict(prodlim::prodlim(form.p,data=pdata),
-                       ## cause=cause,
-                       ## newdata=data.frame(p=sort(p)),
-                       ## times=time,
-                       ## type=ifelse(x$responseType=="survival","surv","cuminc")))
-                       ## plotFrame <- data.frame(Pred=sort(p),Obs=y)
-                       ## plotFrame
-                   }
                })
     }
     plotFrames <- lapply(modelnames,function(f){getXY(f)})
@@ -364,29 +389,20 @@ plotCalibration <- function(x,
                                 sprintf("%1.1f",100*qq[-1]))
         }
     }
-    ## summary <- list(n=NROW(data))
-    ## if (x$responseType%in%c("survival","competing.risks"))
-    ## summary <- c(summary,list("Event"=table(response[response[,"status"]!=0 & response[,"time"]<=time,"event"]),
-    ## "Lost"=sum(response[,"status"]==0 & response[,"time"]<=time),
-    ## "Event.free"=NROW(response[response[,"time"]>time,])))
     out <- list(plotFrames=plotFrames,
-                ## predictions=apppred,
-                time=time,
+                times=tp,
                 cause=cause,
-                pseudo=pseudo,
-                ## summary=summary,
                 control=control,
                 legend=legend,
                 bars=bars,
                 diag=diag,
                 add=add,
-                legend=legend,
                 names=names,
                 method=method,
                 axes=axes,
                 percent=percent,
                 hanging=hanging,
-                showFrequencies=showFrequencies,
+                show.frequencies=show.frequencies,
                 col=col,
                 ylim=ylim,
                 xlim=xlim,
@@ -397,11 +413,8 @@ plotCalibration <- function(x,
                 pch=pch,
                 lty=lty,
                 type=type,
-                NF=NF,
-                pseudo.col=pseudo.col,
-                pseudo.pch=pseudo.pch,
-                showPseudo=showPseudo,
-                jack.density=jack.density)
+                NF=NF)
+                
     if (method=="nne")
         out <- c(out,list(bandwidth=sapply(plotFrames,
                                            function(x)attr(x,"bandwidth"))))
@@ -422,7 +435,7 @@ plotCalibration <- function(x,
             pf <- na.omit(plotFrames[[1]])
             Pred <- pf$Pred
             Obs <- pf$Obs
-            if(is.logical(out$legend[1]) && out$legend[1]==FALSE){
+            if (is.character(legend[1]) || legend[1]==TRUE){
                 control$barplot$legend.text <- NULL
             }else{
                 if (is.null(control$barplot$legend.text)){
@@ -464,7 +477,7 @@ plotCalibration <- function(x,
             if (out$hanging){
                 do.call("abline",control$abline)
             }
-            if (out$showFrequencies){
+            if (out$show.frequencies){
                 if(out$hanging){
                     text(x=coord,
                          cex=control$frequencies$cex,
@@ -483,33 +496,49 @@ plotCalibration <- function(x,
             out <- c(out,coords)
         }else{
             nix <- lapply(1:NF,function(f){
-                if (is.null(out$pseudo.col)){
-                    ccrgb=as.list(col2rgb(out$col[f],alpha=TRUE))
-                    names(ccrgb) <- c("red","green","blue","alpha")
-                    ccrgb$alpha <- out$jack.density
-                    jack.col <- do.call("rgb",c(ccrgb,list(max=255)))
-                }
-                else
-                    jack.col <- out$pseudo.col
-                if (is.null(out$pseudo.pch)) out$pseudo.pch <- 1
-                if (out$showPseudo) {
-                    points(out$predictions[,f+1],out$predictions[,1],col=jack.col,pch=out$pseudo.pch)
-                }
                 pf <- out$plotFrames[[f]]
                 pf <- na.omit(pf)
+                ## rug plot predictions
+                if (showRug){
+                    do.call(graphics::rug,c(list(x=pf$Pred,col=control$rug$col[f],lwd=control$rug$lwd[f]*0.5)))
+                }
+                ## show pseudo values 
+                if (showPseudo) {
+                    if (!is.null(control$pseudo$density) & control$pseudo$density>0){
+                        control$pseudo$col <- prodlim::dimColor(control$pseudo$col[f],
+                                                                control$pseudo$density)
+                    }
+                    if ((gotcha <- match("density",names(control$pseudo),nomatch=0))>0){
+                        control$pseudo <- control$pseudo[-gotcha]
+                    }
+                    do.call(points, c(list(x=pframe[model==modelnames[f]][,risk],y=pframe[model==modelnames[f]][[Rvar]]),control$pseudo))
+                }
+                ## add the lines
                 lineF <- lapply(control$lines,function(x)x[[min(f,length(x))]])
                 lineF$x <- pf$Pred
                 lineF$y <- pf$Obs
                 do.call("lines",lineF)
             })
-            if (!(is.logical(out$legend[1]) && out$legend[1]==FALSE)){
-                do.call("legend",control$legend)
+            if (is.character(out$legend[1]) || out$legend[1]==TRUE){
+                legend.coords <- do.call("legend",control$legend)
+                if (!is.null(addtable2plot.DefaultArgs)){
+                    if (is.null(control$addtable2plot[["x"]]))
+                        control$addtable2plot[["x"]] <- legend.coords$rect$left+legend.coords$rect$w
+                    ## strange error: $y does not work as yjust is matched, thus use [["y"]]
+                    if (is.null(control$addtable2plot[["y"]]))
+                        control$addtable2plot[["y"]] <- legend.coords$rect$top-legend.coords$rect$h
+                    do.call(plotrix::addtable2plot,control$addtable2plot)
+                }
             }
         }
         if (out$axes){
             if (out$percent){
-                control$axis2$labels <- paste(100*control$axis2$at,"%")
-                control$axis1$labels <- paste(100*control$axis1$at,"%")
+                if (is.null(control$axis1$labels)){
+                    control$axis1$labels <- paste(100*control$axis1$at,"%")
+                }
+                if (is.null(control$axis2$labels)){
+                    control$axis2$labels <- paste(100*control$axis2$at,"%")
+                }
             }
             if (!out$bars)
                 do.call("axis",control$axis1)
