@@ -21,69 +21,110 @@
 #' @param band Logical. If \code{TRUE} add the confidence band to the output.
 #' @param iid Logical. If \code{TRUE} add the influence function to the output.
 #' @param average.iid Logical. If \code{TRUE} add the average of the influence function over \code{newdata} to the output.
-#' @param nSim.band the number of simulations used to compute the quantiles
+#' @param nsim.band the number of simulations used to compute the quantiles
 #' for the confidence bands.
-#' @param logTransform Should the confidence intervals/bands be computed on the
+#' @param log.transform Should the confidence intervals/bands be computed on the
 #' log(-log) scale and be backtransformed.
 #' Otherwise they are computed on the original scale and truncated (if necessary).
-#' @param productLimit Logical. If true the survival is computed using the product limit estimator.
+#' @param product.limit Logical. If true the survival is computed using the product limit estimator.
 #' Otherwise the exponential approximation is used (i.e. exp(-cumulative hazard)).
 #' @param conf.level Level of confidence.
 #' @param store.iid Implementation used to estimate the influence function and the standard error.
-#' Can be \code{"full"} or \code{"minimal"}. See the details section of \code{\link{calcSeCSC}}.
+#' Can be \code{"full"} or \code{"minimal"}. 
 #' @param ... not used
 #' @author Brice Ozenne broz@@sund.ku.dk, Thomas A. Gerds
 #'     tag@@biostat.ku.dk
-#' @details Note: for Cox regression models with time varying
+#' @details
+#' This function computes the absolute risk as given by formula 2 of (Ozenne et al., 2017).
+#' Confidence intervals and confidence bands can be computed using a first order von Mises expansion.
+#' See the section "Construction of the confidence intervals" in (Ozenne et al., 2017).
+#' 
+#' When setting \code{log.transform} to \code{TRUE}, the standard error that is returned is 
+#' before back-transformation to the original scale.
+#'
+#' A detailed explanation about the meaning of the argument \code{store.iid} can be found
+#' in (Ozenne et al., 2017) Appendix B "Saving the influence functions".
+#' 
+#' Note: for Cox regression models with time varying
 #'     covariates it does not make sense to use this function, because
 #'     the predicted risk has to be a measurable function of the data
 #'     available at the time origin.
 #' 
-#' When setting \code{logTransform} to \code{TRUE}, the standard error that is returned is 
-#' before back-transformation to the original scale.
-#' 
 #' @return A list containing:
 #' \itemize{
 #' \item{absRisk}: (data table) the predictions for each subject (in rows) and each time (in columns).
 #' \item{absRisk.se}: (data table) the standard errors of the predictions.
 #' \item(absRisk.iid): (array) the value of the influence of each subject used to fit the object (dim 3)
 #' for each subject in newdata (dim 1) and each time (dim 2).
+#' \item(absRisk.average.iid): (matrix) the average value of the influence over the subjects in newdata,
+#' for each subject used to fit the object (dim 1) and each time (dim 2).
 #' \item{times}: (vector) the evaluation times.
 #' }
-#'  
-#' @examples 
+#'
+#' @references
+#' Brice Ozenne, Anne Lyngholm Sorensen, Thomas Scheike, Christian Torp-Pedersen and Thomas Alexander Gerds.
+#' riskRegression: Predicting the Risk of an Event using Cox Regression Models.
+#' The R Journal (2017) 9:2, pages 440-460.
+#' 
+#' @examples
+#' library(survival)
+#' 
+#' ## generate data
 #' set.seed(5)
-#' d <- sampleData(80,outcome="comp")
-#' nd <- sampleData(4,outcome="comp")
-#' d$time <- round(d$time,1)
+#' d <- sampleData(80,outcome="comp") ## training dataset
+#' nd <- sampleData(4,outcome="comp") ## validation dataset
+#' d$time <- round(d$time,1) ## create tied events
 #' ttt <- sort(sample(x = unique(d$time), size = 10))
 #'
-#' # coxph function
-#' CSC.fit <- CSC(Hist(time,event)~ X3+X8,data=d, method = "breslow")
-#' x= predict(CSC.fit,newdata=nd,times=1:10,cause=1,se=1L)
-#' px=print(x)
-#' px
-#' x2 = predict(CSC.fit,newdata=nd,times=1:10,cause=1,se=1L,
-#'            logTransform = TRUE)
-#' 
-#' predCSC <- predict(CSC.fit, newdata = d, cause = 2, times = ttt)
-#' predCSC.se <- predict(CSC.fit, newdata = d[1:5,], cause = 2, times = ttt,
-#'                       se = TRUE,keep.newdata=TRUE)
-#' predCSC.iid <- predict(CSC.fit, newdata = d[1:5,],
-#'                        cause = 2, times = ttt, iid = TRUE)
+#' ## estimate a CSC model based on the coxph function
+#' CSC.fit <- CSC(Hist(time,event)~ X3+X8, data=d, method = "breslow")
 #'
-#' # predCSC.se$absRisk.se
-#' # sqrt(apply(predCSC.iid$absRisk.iid[,1,]^2,1,function(x){sum(x)}))
-#' ## strata
+#' ## compute the absolute risk of cause 1, in the validation dataset
+#' ## at time 1:10
+#' CSC.risk <-  predict(CSC.fit, newdata=nd, times=1:10, cause=1)
+#' CSC.risk
+#'
+#' ## add the standard error/confidence intervals
+#' ## (computed on the log log scale and backtransformed)
+#' CSC.riskSE <-  predict(CSC.fit,newdata=nd,times=1:10,cause=1,se=TRUE,
+#'                         log.transform = TRUE)
+#' as.data.table(CSC.riskSE)[1:5]
+#' exp(-exp(
+#'  log(-log(CSC.riskSE$absRisk)) - 1.96 * CSC.riskSE$absRisk.se
+#' ))
+#'
+#' ## extract the iid for the absolute risk
+#' CSC.iid <- predict(CSC.fit, newdata = d, se = TRUE,
+#'                    cause = 1, times = ttt[1], iid = TRUE,
+#'                    log.transform = FALSE)
+#' rowMeans(CSC.iid$absRisk.iid[,1,]) ## the iid decomposition has 0 expectation
+#' sqrt(rowSums(CSC.iid$absRisk.iid[,1,]^2))[1:5]
+#' as.data.table(CSC.iid)[1:5]
+#'
+#' ## same but the iid decomposition is averaged over the patients
+#' CSC.aviid <- predict(CSC.fit, newdata = d,
+#'                    cause = 1, times = ttt[1],
+#'                    average.iid = TRUE,
+#'                    log.transform = FALSE)
+#' CSC.aviid$absRisk.average.iid[1:5,]
+#' colMeans(CSC.iid$absRisk.iid[,1,1:5])
+#' 
+#' ## compute absolute risks with CI for cause 2
+#' ## (without displaying the value of the covariates)
+#' predict(CSC.fit,newdata=nd,times=1:10,cause=2,se=TRUE,
+#'         log.transform = TRUE, keep.newdata = FALSE)
+#'
+#' ## other example
+#' library(survival)
 #' CSC.fit.s <- CSC(list(Hist(time,event)~ strata(X1)+X2+X9,
 #'  Hist(time,event)~ X2+strata(X4)+X8+X7),data=d, method = "breslow")
-#' predict(CSC.fit.s,cause=1,times=ttt,se=1L)
-#' # cph function
-#' CSC.cph <- CSC(Hist(time,event)~ X1+X2,data=d, method = "breslow", fitter = "cph")
+#' predict(CSC.fit.s,cause=1,times=ttt,se=1L) ## note: absRisk>1 due to small number of observations
 #' 
+#' ## using the cph function instead of coxph
+#' CSC.cph <- CSC(Hist(time,event)~ X1+X2,data=d, method = "breslow", fitter = "cph")#' 
 #' predict(CSC.cph, newdata = d, cause = 2, times = ttt)
 #' 
-#' # landmark analysis
+#' ## landmark analysis
 #' T0 <- 1
 #' predCSC_afterT0 <- predict(CSC.fit, newdata = d, cause = 2, times = ttt[ttt>T0], landmark = T0)
 #' predCSC_afterT0
@@ -102,9 +143,9 @@ predict.CauseSpecificCox <- function(object,
                                      band = FALSE,
                                      iid = FALSE,
                                      average.iid = FALSE,
-                                     nSim.band = 1e4,
-                                     logTransform = FALSE,
-                                     productLimit = TRUE,
+                                     nsim.band = 1e4,
+                                     log.transform = TRUE,
+                                     product.limit = TRUE,
                                      conf.level=0.95,
                                      store.iid="full",
                                      ...){
@@ -112,7 +153,7 @@ predict.CauseSpecificCox <- function(object,
     if(missing(newdata)){newdata <- eval(object$call$data)}
     data.table::setDT(newdata)
     
-    survtype <- object$survtype
+    surv.type <- object$surv.type
     if (length(cause) > 1){
         stop(paste0("Can only predict one cause. Provided are: ", 
                     paste(cause, collapse = ", "), sep = ""))
@@ -120,7 +161,7 @@ predict.CauseSpecificCox <- function(object,
     if (missing(cause)) {
         cause <- object$theCause
     }
-
+	
     ## causes
     # NOTE: cannot use only eventtimes of cause 1 otherwise wrong estimation of the survival in the absolute risk
     causes <- object$causes
@@ -130,10 +171,13 @@ predict.CauseSpecificCox <- function(object,
     eTimes <- object$eventTimes
     
     if (any(match(as.character(cause), causes, nomatch = 0)==0L))
-        stop(paste0("Requested cause ",as.character(cause)," does not match fitted causes which are:\n ",paste0("- ",causes,collapse="\n")))
+        stop(paste0("Cannot find all requested cause(s) ...\n\n", 
+                    "Requested cause(s): ", paste0(cause, collapse = ", "), 
+                    "\n Available causes: ", paste(causes, collapse = ", "), 
+                    "\n"))
     ## stopifnot(match(as.character(cause), causes, nomatch = 0) != 
     ## 0)
-    if (survtype == "survival") {
+    if (surv.type == "survival") {
         if (object$theCause != cause) 
             stop("Object can be used to predict cause ", object$theCause, 
                  " but not ", cause, ".\nNote: the cause can be specified in CSC(...,cause=).")
@@ -146,12 +190,13 @@ predict.CauseSpecificCox <- function(object,
     }
   
     ## Confidence bands
-    if(band>0){
-        iid.save <- iid
-        se.save <- se
+    if(band>0){ # used to force the computation of the influence function + standard error to get the confidence bands
         iid <- TRUE
         se <- TRUE
     }
+    # original arguments to make this operation invisible for the user
+    iid.save <- iid
+    se.save <- se
         
     # relevant event times to use  
     eventTimes <- eTimes[which(eTimes <= max(times))] 
@@ -165,7 +210,7 @@ predict.CauseSpecificCox <- function(object,
     nEventTimes <- length(eventTimes)
     nCause <- length(causes)
 
-    if (survtype == "hazard") {
+    if (surv.type == "hazard") {
         
         ls.hazard <- vector(mode = "list", length = nCause)
         ls.cumhazard <- vector(mode = "list", length = nCause)
@@ -174,9 +219,9 @@ predict.CauseSpecificCox <- function(object,
         M.etimes.max <- matrix(NA, nrow = new.n, ncol = nCause)
         
         for(iterC in 1:nCause){
-          infoVar <- CoxVariableName(object$models[[iterC]])
+          infoVar <- coxVariableName(object$models[[iterC]])
 
-          if(iterC == index.cause || productLimit || se || iid || average.iid){            
+          if(iterC == index.cause || product.limit || se || iid || average.iid){            
               typeC <- c("hazard","cumhazard")
           }else{
               typeC <- "cumhazard"
@@ -196,21 +241,21 @@ predict.CauseSpecificCox <- function(object,
           }
           
           ## linear predictor for the new observations
-          M.eXb[,iterC] <- exp(CoxLP(object$models[[iterC]], data = newdata, center = FALSE))
+          M.eXb[,iterC] <- exp(coxLP(object$models[[iterC]], data = newdata, center = FALSE))
           
           ## strata for the new observations
-          M.strata[,iterC] <- as.numeric(CoxStrata(object$models[[iterC]], data = newdata, 
+          M.strata[,iterC] <- as.numeric(coxStrata(object$models[[iterC]], data = newdata, 
                                                    sterms = infoVar$sterms, 
-                                                   stratavars = infoVar$stratavars, 
+                                                   strata.vars = infoVar$strata.vars, 
                                                    levels = levels(baseline$strata), 
-                                                   stratalevels = infoVar$stratalevels))-1
+                                                   strata.levels = infoVar$strata.levels))-1
           
           ## last time by strata
           M.etimes.max[,iterC] <- baseline$lastEventTime[M.strata[,iterC]+1]
         }
         
         
-    }else if (survtype == "survival"){
+    }else if (surv.type == "survival"){
         
         #### cause ####
         
@@ -226,16 +271,16 @@ predict.CauseSpecificCox <- function(object,
 
         
         ## linear predictor for the new observations
-        eXb_Cause <- cbind(exp(CoxLP(object$models[[paste("Cause",cause)]], data = newdata, center = FALSE)))
+        eXb_Cause <- cbind(exp(coxLP(object$models[[paste("Cause",cause)]], data = newdata, center = FALSE)))
         
         ## strata for the new observations
-        infoVar_Cause <- CoxVariableName(object$models[[paste("Cause",cause)]])
-        strata_Cause <- CoxStrata(object$models[[paste("Cause",cause)]],
+        infoVar_Cause <- coxVariableName(object$models[[paste("Cause",cause)]])
+        strata_Cause <- coxStrata(object$models[[paste("Cause",cause)]],
                                   data = newdata,
                                   sterms = infoVar_Cause$sterms,
-                                  stratavars = infoVar_Cause$stratavars,
+                                  strata.vars = infoVar_Cause$strata.vars,
                                   levels = levels(baseline_Cause$strata),
-                                  stratalevels = infoVar_Cause$stratalevels)
+                                  strata.levels = infoVar_Cause$strata.levels)
         
         
         #### overall ####
@@ -248,15 +293,15 @@ predict.CauseSpecificCox <- function(object,
                                        se = FALSE)
         
         ## linear predictor for the new observations
-        eXb_Overall <- cbind(exp(CoxLP(object$models[["OverallSurvival"]], data = newdata, center = FALSE)))
+        eXb_Overall <- cbind(exp(coxLP(object$models[["OverallSurvival"]], data = newdata, center = FALSE)))
         ## strata for the new observations
-        infoVar_Overall <- CoxVariableName(object$models[["OverallSurvival"]])
-        strata_Overall <- CoxStrata(object$models[["OverallSurvival"]],
+        infoVar_Overall <- coxVariableName(object$models[["OverallSurvival"]])
+        strata_Overall <- coxStrata(object$models[["OverallSurvival"]],
                                   data = newdata,
                                   sterms = infoVar_Overall$sterms,
-                                  stratavars = infoVar_Overall$stratavars,
+                                  strata.vars = infoVar_Overall$strata.vars,
                                   levels = levels(baseline_Overall$strata),
-                                  stratalevels = infoVar_Overall$stratalevels)
+                                  strata.levels = infoVar_Overall$strata.levels)
         
         
         #### store
@@ -283,8 +328,8 @@ predict.CauseSpecificCox <- function(object,
                           nData = new.n,
                           cause = index.cause - 1, 
                           nCause = nCause,
-                          survtype = survtype=="survival",
-                          productLimit = productLimit)
+                          survtype = (surv.type=="survival"),
+                          productLimit = product.limit)
     
     #### standard error ####
     if(se || iid || average.iid){
@@ -295,7 +340,7 @@ predict.CauseSpecificCox <- function(object,
         ## design matrix
         new.LPdata <- list()
         for(iCause in 1:nCause){
-            infoVar <- CoxVariableName(object$models[[iCause]])
+            infoVar <- coxVariableName(object$models[[iCause]])
             
             if(length(infoVar$lpvars) > 0){
                 new.LPdata[[iCause]] <- model.matrix(object$models[[iCause]], newdata)
@@ -306,7 +351,7 @@ predict.CauseSpecificCox <- function(object,
 
 
         nVar <- unlist(lapply(object$models,function(m){
-            length(CoxVariableName(m)$lpvars)
+            length(coxVariableName(m)$lpvars)
         }))
 
         out.seCSC <- calcSeCSC(object,
@@ -323,8 +368,8 @@ predict.CauseSpecificCox <- function(object,
                                cause = which(causes == cause),
                                nCause = nCause,
                                nVar = nVar,
-                               survtype = survtype,
-                               logTransform = logTransform,
+                               surv.type = surv.type,
+                               log.transform = log.transform,
                                export = c("iid"[iid==TRUE],"se"[se==TRUE],"average.iid"[average.iid==TRUE]),
                                store.iid = store.iid)
     }
@@ -336,7 +381,7 @@ predict.CauseSpecificCox <- function(object,
         out$absRisk.se <- out.seCSC$se[,ootimes,drop=FALSE]
         zval <- qnorm(1-(1-conf.level)/2, 0,1)
 
-        if(logTransform){
+        if(log.transform){
             out$absRisk.lower <- exp(-exp(log(-log(out$absRisk)) + zval*out$absRisk.se))
             out$absRisk.upper <- exp(-exp(log(-log(out$absRisk)) - zval*out$absRisk.se))
         }else{            
@@ -350,14 +395,13 @@ predict.CauseSpecificCox <- function(object,
         out$absRisk.iid <- out.seCSC$iid[,ootimes,,drop=FALSE]
     }
     if(average.iid){
-        out$absRisk.iid <- out.seCSC$iid[,ootimes,drop=FALSE]
+        out$absRisk.average.iid <- out.seCSC$average.iid[,ootimes,drop=FALSE]
     }
     if(band>0){
         
         out$quantile.band <- confBandCox(iid = out$absRisk.iid,
                                          se = out$absRisk.se,
-                                         times = times,                                         
-                                         n.sim = nSim.band,
+                                         n.sim = nsim.band,
                                          conf.level = conf.level)
             
         if(iid.save==FALSE){
@@ -366,7 +410,7 @@ predict.CauseSpecificCox <- function(object,
 
         quantile95 <- colMultiply_cpp(out$absRisk.se,out$quantile.band)
                 
-        if(logTransform){
+        if(log.transform){
             out$absRisk.lowerBand <- exp(-exp(log(-log(out$absRisk)) + quantile95))
             out$absRisk.upperBand <- exp(-exp(log(-log(out$absRisk)) - quantile95))
         }else{            
@@ -383,13 +427,13 @@ predict.CauseSpecificCox <- function(object,
     }    
     if(keep.times){out$times <- times}
     if(keep.newdata==TRUE){
-        allVars <- unique(unlist(lapply(object$models, function(m){CoxCovars(m)})))
+        allVars <- unique(unlist(lapply(object$models, function(m){coxCovars(m)})))
         if(length(allVars)>0){
             out$newdata <- newdata[, allVars, with = FALSE]
         }
     }
     if(keep.strata==TRUE){
-        allStrata <- unique(unlist(lapply(object$models, function(m){CoxVariableName(m)$stratavars.original})))
+        allStrata <- unique(unlist(lapply(object$models, function(m){coxVariableName(m)$strata.vars.original})))
         if (length(allStrata)>0){
             newdata <- copy(newdata[,allStrata, with = FALSE])
             newdata[, (allStrata) := lapply(allStrata, function(col){paste0(col,"=",.SD[[col]])})]
@@ -397,7 +441,8 @@ predict.CauseSpecificCox <- function(object,
         }
     }
     out$conf.level <- conf.level
-    out <- c(out,list(se = se, band = band, nSim.band = nSim.band, logTransform = logTransform))
+    transformation.absRisk <- if(log.transform){function(x){log(-log(1-x))}}else{NA}
+    out <- c(out,list(se = se.save, band = band, nsim.band = nsim.band, transformation.absRisk = transformation.absRisk))
     class(out) <- "predictCSC"
     return(out)
 }
